### Name: parse.par
### Title: Select and reshape parameter vectors
### Aliases: parse.par
### Keywords: utilities

### ** Examples

# Let's say that the name of the model is "bivariate.probit", and
# the corresponding describe function is describe.bivariate.probit(), 
# which identifies mu1 and mu2 as systematic components, and an 
# ancillary parameter rho, which may be parameterized, but is estimated 
# as a scalar by default.  Let par be the parameter vector (including 
# parameters for rho), formulae a user-specified formula, and mydata
# the user specified data frame.  

# Acceptable combinations of parse.par() and model.matrix() are as follows:
## Setting up
## Not run: 
##D data(sanction)
##D formulae <- cbind(import, export) ~ coop + cost + target
##D fml <- parse.formula(formulae, model = "bivariate.probit")
##D D <- model.frame(fml, data = sanction)
##D terms <- attr(D, "terms")
##D 
##D ## Intuitive option
##D Beta <- parse.par(par, terms, shape = "vector", eqn = c("mu1", "mu2"))
##D X <- model.matrix(fml, data = D, shape = "stacked", eqn = c("mu1", "mu2")
##D eta <- X 
##D 
##D ## Memory-efficient (compact) option (default)
##D Beta <- parse.par(par, terms, eqn = c("mu1", "mu2"))    
##D X <- model.matrix(fml, data = D, eqn = c("mu1", "mu2"))
##D eta <- X 
##D 
##D ## Computationally-efficient (array) option
##D Beta <- parse.par(par, terms, shape = "vector", eqn = c("mu1", "mu2"))
##D X <- model.matrix(fml, data = D, shape = "array", eqn = c("mu1", "mu2"))
##D eta <- apply(X, 3, '
## End(Not run)


